@@ -657,6 +657,7 @@ class Row:
         self.__data = data
     def get(self, name):
         if self.offsets[name]['count'] > 1:
+            log.info(color.cyan('Row offset %s'), name)
             #print(name, self.offsets[name], self.__data[self.offsets[name]['position']:self.offsets[name]['position']+self.offsets[name]['count']])
             return self.__data[self.offsets[name]['position']:self.offsets[name]['position']+self.offsets[name]['count']]
         return self.__data[self.offsets[name]['position']]
@@ -758,7 +759,7 @@ class Result():
         self.items.append(item)
 
 def debug(query, params):
-    params_debug = tuple([str(param) for param in params])
+    params_debug = tuple(["'"+str(param)+"'" for param in params])
 
     query_debug = ''
     for line in query.splitlines():
